@@ -1,15 +1,13 @@
 package App::lcpan::Cmd::debian_dist2deb;
 
-our $DATE = '2017-01-13'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2017-01-16'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use Log::Any::IfLOG '$log';
 
-use Clone::Util qw(modclone);
-
 require App::lcpan;
 
 our %SPEC;
@@ -31,6 +29,16 @@ _
             summary => 'Check each distribution if its Debian package exists, using Dist::Util::Debian::dist_has_deb',
             schema => 'bool*',
         },
+        use_allpackages => {
+            summary => 'Will be passed to Dist::Util::Debian::dist_has_deb',
+            description => <<'_',
+
+Using this option is faster if you need to check existence for many Debian
+packages. See <pm:Dist::Util::Debian> documentation for more details.
+
+_
+            schema => 'bool*',
+        },
     },
 };
 sub handle_cmd {
@@ -46,11 +54,14 @@ sub handle_cmd {
 
     push @fields, "exists" if $args{check_exists};
 
+    my $opts = {};
+    $opts->{use_allpackages} = 1 if $args{use_allpackages};
+
     for my $dist (@{ $args{dists} }) {
         my $deb = Dist::Util::Debian::dist2deb($dist);
         my $row = {dist => $dist, deb => $deb};
         if ($args{check_exists}) {
-            $row->{exists} = Dist::Util::Debian::deb_exists($deb);
+            $row->{exists} = Dist::Util::Debian::deb_exists($opts, $deb);
         }
         push @rows, $row;
     }
@@ -72,7 +83,7 @@ App::lcpan::Cmd::debian_dist2deb - Convert dist name to Debian package name
 
 =head1 VERSION
 
-This document describes version 0.001 of App::lcpan::Cmd::debian_dist2deb (from Perl distribution App-lcpan-CmdBundle-debian), released on 2017-01-13.
+This document describes version 0.002 of App::lcpan::Cmd::debian_dist2deb (from Perl distribution App-lcpan-CmdBundle-debian), released on 2017-01-16.
 
 =head1 FUNCTIONS
 
@@ -107,6 +118,13 @@ Defaults to C<~/cpan>.
 
 Filename of index.
 
+=item * B<use_allpackages> => I<bool>
+
+Will be passed to Dist::Util::Debian::dist_has_deb.
+
+Using this option is faster if you need to check existence for many Debian
+packages. See L<Dist::Util::Debian> documentation for more details.
+
 =back
 
 Returns an enveloped result (an array).
